=================================================
Migrate an already existing package to use pkglts
=================================================

Ok, you already have a well defined package running but you are interested in
using pkglts to add new features in the future.

.. note:: You don't have to break anything

The following steps will guide you through the process of adding pkglts management
to your existing package with minimal troubles.


